==> valknut-0.4.0a.tar.bz2: valknut-0.4.0a/valknut/dcedittransfer.h <==
/***************************************************************************
                          dcedittransfer.h  -  description
                             -------------------
    begin                : Don Dez 5 2002
    copyright            : (C) 2002 by Mathias Kster
    email                : mathen@users.berlios.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DCEDITTRANSFER_H
#define DCEDITTRANSFER_H

#include <qwidget.h>

#include <dclib/core/clist.h>
#include <dclib/dcobject.h>

#include "DCDialogEditTransfer.h"

/**
  *@author Mathias Kster
  */

class DCEditTransfer : public QDialog, public Ui::DCDialogEditTransfer  {
Q_OBJECT

public: 
	/** construtor */
	DCEditTransfer(QWidget *parent=0, const char *name=0);
	/** destructor */
	virtual ~DCEditTransfer();

	/** */
	void InitDocument();
	/** */
	void Init(QString & nick, QString & hubname, QString & hubhost, CList<DCHubObject> * list );

private:
	/** */
	CList<DCHubObject> * m_pHubObjectList;

private slots:
	/** */
	void slotKnownHubsChange( const QString & );
};

#endif

==> valknut-0.4.4.tar.bz2: valknut-0.4.4/valknut/dcedittransfer.h <==
/***************************************************************************
                          dcedittransfer.h  -  description
                             -------------------
    begin                : Don Dez 5 2002
    copyright            : (C) 2002 by Mathias Kster
    email                : mathen@users.berlios.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DCEDITTRANSFER_H
#define DCEDITTRANSFER_H

#include <qwidget.h>

#include <dclib/core/clist.h>
#include <dclib/dcobject.h>

#include "DCDialogEditTransfer.h"

/**
  *@author Mathias Kster
  */

class DCEditTransfer : public QDialog, public Ui::DCDialogEditTransfer  {
Q_OBJECT

public: 
	/** construtor */
	DCEditTransfer( QWidget * parent = 0 );
	/** destructor */
	virtual ~DCEditTransfer();

	/** */
	void InitDocument();
	/** */
	void Init(QString & nick, QString & hubname, QString & hubhost, CList<DCHubObject> * list );

private:
	/** */
	CList<DCHubObject> * m_pHubObjectList;

private slots:
	/** */
	void slotKnownHubsChange( const QString & );
};

#endif
